@@ -6,7 +6,7 @@ import java.lang.annotation.RetentionPolicy;
 import java.lang.annotation.Target;
 
 /**
- * Annotation used with {@link JsonTypeInfo} to indicate sub-types of serializable
+ * Annotation used with {@link JsonTypeInfo} to indicate subtypes of serializable
  * polymorphic types, and to associate logical names used within JSON content
  * (which is more portable than using physical Java class names).
  *<p>
@@ -27,6 +27,16 @@ public @interface JsonSubTypes {
      */
     public Type[] value();
 
+    /**
+     * Subtypes of the annotated type may have logical type name and names properties.
+     * When set to true, logical type name and names are going to be checked
+     * for repeated values. Repeated values are considered a definition violation
+     * during that check.
+     *
+     * @since 2.14
+     */
+    public boolean failOnRepeatedNames() default false;
+
     /**
      * Definition of a subtype, along with optional name(s). If no name is defined
      * (empty Strings are ignored), class of the type will be checked for {@link JsonTypeName}
